@@ -1,6 +1,6 @@
 /***************************************************************************
                              SRC/mixmod/Kernel/Algo/SEMAlgo.cpp  description
-    copyright            : (C) MIXMOD Team - 2001-2014
+    copyright            : (C) MIXMOD Team - 2001-2016
     email                : contact@mixmod.org
  ***************************************************************************/
 
@@ -96,7 +96,8 @@ void SEMAlgo::run(Model *& model) {
 		model->editDebugInformation();
 	}
 	
-	Model * bestModel = new Model(model);
+	//Model * bestModel = new Model(model);
+    std::unique_ptr<Model>  bestModel(new Model(model));
 	double bestLL = bestModel->getLogLikelihood(true); // true : to update fik
 
 	// others iterations
@@ -120,15 +121,16 @@ void SEMAlgo::run(Model *& model) {
 				cout << "BestModel prend la valeur de LastModel" << endl;
 
 			bestLL = lastLL;
-			delete bestModel;
-			bestModel = new Model(model);
+			//delete bestModel;
+			//bestModel = new Model(model);
+            bestModel.reset(new Model(model));
 		}
 		_indexIteration++;
 	}
 
 	bestModel->Estep(); // E step to update Tik and fik
 	// update model (to output)
-	model = bestModel;
+	model = bestModel.release();
 }
 
 }
