@@ -1,6 +1,6 @@
 /***************************************************************************
                              SRC/mixmod/Kernel/Model/Model.h  description
-    copyright            : (C) MIXMOD Team - 2001-2014
+    copyright            : (C) MIXMOD Team - 2001-2016
     email                : contact@mixmod.org
  ***************************************************************************/
 
@@ -172,9 +172,13 @@ public:
 	/** @brief Compute the entropy
 		@return The entropy
 	 */
-
 	double getEntropy();
 
+	/** @brief Compute the entropy matrix (for massiccc's visualization)
+		@return The entropy matrix
+	 */
+	vector< vector<double> > getEntropyMatrix();
+
 	/** @brief Compute the completed log-likelihood
 		@return The completed log-likelihood
 	 */
