@@ -1,6 +1,6 @@
 /***************************************************************************
                              SRC/mixmod/Kernel/Parameter/GaussianGeneralParameter.cpp  description
-    copyright            : (C) MIXMOD Team - 2001-2014
+    copyright            : (C) MIXMOD Team - 2001-2016
     email                : contact@mixmod.org
  ***************************************************************************/
 
@@ -100,13 +100,56 @@ GaussianGeneralParameter::GaussianGeneralParameter(
 		if (!paramFile.is_open()) {
 			THROW(InputException, wrongParamFileName);
 		}
-		input(paramFile);
+    input(paramFile);
 		paramFile.close();
 	}
 
 	updateTabInvSigmaAndDet(); // method of XEMGaussianParameter
 }
 
+//-------------------------------------------------------------------------------------
+//constructeur avec une initialisation USER from file for heterogeneous models
+//-------------------------------------------------------------------------------------
+GaussianGeneralParameter::GaussianGeneralParameter(
+		int64_t iNbCluster, 
+		int64_t iPbDimension, 
+		ModelType * iModelType, 
+		std::string & iFileName,
+    int64_t iNbVariable_binary,
+    std::vector< int64_t > inbFactor)
+: GaussianEDDAParameter(iNbCluster, iPbDimension, iModelType) 
+{
+	int64_t k;
+	__storeDim = _pbDimension * (_pbDimension + 1) / 2;
+	_tabShape = new DiagMatrix*[_nbCluster];
+	_tabOrientation = new GeneralMatrix*[_nbCluster];
+	_tabLambda = new double [_nbCluster];
+
+	for (k = 0; k < _nbCluster; k++) {
+		_tabShape[k] = new DiagMatrix(_pbDimension); //Id
+		_tabOrientation[k] = new GeneralMatrix(_pbDimension); //Id
+		_tabLambda[k] = 1.0;
+
+		// _tabSigma, _tabInvSigma, _tabWk will be initialized in XEMGaussianEDDAparameter
+		_tabInvSigma[k] = new SymmetricMatrix(_pbDimension); //Id
+		_tabSigma[k] = new SymmetricMatrix(_pbDimension); // Id
+		_tabWk[k] = new SymmetricMatrix(_pbDimension); //Id
+		*_tabWk[k] = 1.0;
+	}
+	_W = new SymmetricMatrix(_pbDimension); //Id
+
+	// read parameters in file iFileName//
+	if (iFileName.compare("") != 0) {
+		std::ifstream paramFile(iFileName.c_str(), ios::in);
+		if (!paramFile.is_open()) {
+			THROW(InputException, wrongParamFileName);
+		}
+    input(paramFile, iNbVariable_binary, inbFactor);
+		paramFile.close();
+	}
+
+	updateTabInvSigmaAndDet(); // method of XEMGaussianParameter
+}
 //-------------------------------------------------------------------------------------
 //constructeur avec une initialisation USER from containers
 //-------------------------------------------------------------------------------------
@@ -722,7 +765,8 @@ double GaussianGeneralParameter::flury(double F) {
 	double * Ori = _tabOrientation[0]->getStore();
 	GaussianData * data = _model->getGaussianData();
 	double * D_im = data->getTmpTabOfSizePbDimension();
-	double * D_il = new double[_pbDimension];
+	//double * D_il = new double[_pbDimension];
+	std::unique_ptr<double[]> D_il(new double[_pbDimension]);    
 	int64_t il_p, im_p;
 	double iSim_iSil_k;
 
@@ -835,7 +879,7 @@ double GaussianGeneralParameter::flury(double F) {
 		iter++;
 	}
 
-	delete[] D_il;
+	//delete[] D_il;
 	return F;
 }
 
@@ -851,17 +895,20 @@ double GaussianGeneralParameter::getLogLikelihoodOne() const {
 	int64_t i;
 	GaussianData * data = _model->getGaussianData();
 	double logLikelihoodOne; // Log-likelihood for k=1
-	double * Mean = new double[_pbDimension];
+	//double * Mean = new double[_pbDimension];
+	std::unique_ptr<double[]> Mean(new double[_pbDimension]);
 	double ** y = data->_yStore;
 	double * yi;
-	SymmetricMatrix * Sigma = new SymmetricMatrix(_pbDimension); //Id
-	SymmetricMatrix * W = new SymmetricMatrix(_pbDimension, 0.0); // 0.0
+	//SymmetricMatrix * Sigma = new SymmetricMatrix(_pbDimension); //Id
+	//SymmetricMatrix * W = new SymmetricMatrix(_pbDimension, 0.0); // 0.0
+	std::unique_ptr<SymmetricMatrix> Sigma(new SymmetricMatrix(_pbDimension)); //Id
+	std::unique_ptr<SymmetricMatrix> W(new SymmetricMatrix(_pbDimension, 0.0)); // 0.0
 	double norme;
 	double * weight = data->_weight;
 
 	//  Mean Estimator (empirical estimator)
 	double totalWeight = data->_weightTotal;
-	computeMeanOne(Mean, weight, y, nbSample, totalWeight);
+	computeMeanOne(Mean.get(), weight, y, nbSample, totalWeight);
 	weight = data->_weight;
 
 	/* Compute the Cluster Scattering Matrix W */
@@ -880,15 +927,15 @@ double GaussianGeneralParameter::getLogLikelihoodOne() const {
 	//  logDet   = W->detDiag(minDeterminantDiagWValueError);  // virtual
 	//  detDiagW = powAndCheckIfNotNull(logDet ,1.0/_pbDimension);
 
-	Sigma->equalToMatrixDividedByDouble(W, totalWeight); // virtual
+	Sigma->equalToMatrixDividedByDouble(W.get(), totalWeight); // virtual
 
 	// inverse of Sigma
 
 	//SymmetricMatrix * SigmaMoins1 = new SymmetricMatrix(_pbDimension);
-	Matrix* SigmaMoins1 = NULL;
+	Matrix* SigmaMoins1_p = NULL;
 	//SigmaMoins1->inverse(Sigma);// virtual
-	Sigma->inverse(SigmaMoins1);
-
+	Sigma->inverse(SigmaMoins1_p);
+    std::unique_ptr<Matrix> SigmaMoins1(SigmaMoins1_p); //only for a safe deletion of SigmaMoins1_p
 	NumericException error = NumericException(minDeterminantSigmaValueError);
 	double detSigma = Sigma->determinant(error); // virtual
 
@@ -907,11 +954,11 @@ double GaussianGeneralParameter::getLogLikelihoodOne() const {
 	logLikelihoodOne += totalWeight * (data->getPbDimensionLog2Pi() + log(detSigma));
 	logLikelihoodOne *= -0.5;
 
-	delete W;
-	delete Sigma;
-	delete SigmaMoins1;
+	//delete W;
+	//delete Sigma;
+	//delete SigmaMoins1;
 
-	delete[] Mean;
+	//delete[] Mean;
 
 	return logLikelihoodOne;
 }
