@@ -3,4 +3,4 @@ data(heterodatatest)
 data(heterodatatrain)
 learn<-mixmodLearn(heterodatatrain[-1], knownLabels=heterodatatrain$V1)
 predict<-mixmodPredict(heterodatatest[-1], classificationRule=learn["bestResult"])
-missclassified<-sum(predict@partition-heterodatatest$V1)
+missclassified<-sum(as.integer(predict@partition)-as.integer(heterodatatest$V1))
